@@ -46,6 +46,8 @@ from cgi import escape
 from rss import Listing
 from opml import GetOpmlData, ExportOpmlData
 
+from urllib2 import install_opener, build_opener
+
 from socket import setdefaulttimeout
 timeout = 5
 setdefaulttimeout(timeout)
@@ -161,8 +163,6 @@ class Download(Thread):
         key_lock = get_lock(self.key)
         if key_lock != None:
             if use_proxy:
-                from urllib2 import install_opener, build_opener
-                install_opener(build_opener(proxy))
                 self.listing.updateFeed(self.key, self.config.getExpiry(), proxy=proxy, imageCache=self.config.getImageCache() )
             else:
                 self.listing.updateFeed(self.key, self.config.getExpiry(), imageCache=self.config.getImageCache() )
@@ -181,6 +181,15 @@ class DownloadBar(gtk.ProgressBar):
             self.config = config
             self.current = 0
             self.single = single
+            (use_proxy, proxy) = self.config.getProxy()
+            if use_proxy:
+                opener = build_opener(proxy)
+                opener.addheaders = [('User-agent', 'Mozilla/5.0 (compatible; Maemo 5;) FeedingIt 0.6.1')]
+                install_opener(opener)
+            else:
+                opener = build_opener()
+                opener.addheaders = [('User-agent', 'Mozilla/5.0 (compatible; Maemo 5;) FeedingIt 0.6.1')]
+                install_opener(opener)
 
             if self.total>0:
                 self.set_text("Updating...")
@@ -516,7 +525,7 @@ class DisplayArticle(hildon.StackableWindow):
 
 
 class DisplayFeed(hildon.StackableWindow):
-    def __init__(self, listing, feed, title, key, config):
+    def __init__(self, listing, feed, title, key, config, updateDbusHandler):
         hildon.StackableWindow.__init__(self)
         self.listing = listing
         self.feed = feed
@@ -524,6 +533,7 @@ class DisplayFeed(hildon.StackableWindow):
         self.set_title(title)
         self.key=key
         self.config = config
+        self.updateDbusHandler = updateDbusHandler
         
         self.downloadDialog = False
         
@@ -858,7 +868,7 @@ class FeedingIt:
         except:
             # If feed_lock doesn't exist, we can open the feed, else we do nothing
             self.feed_lock = get_lock(key)
-            self.disp = DisplayFeed(self.listing, self.listing.getFeed(key), self.listing.getFeedTitle(key), key, self.config)
+            self.disp = DisplayFeed(self.listing, self.listing.getFeed(key), self.listing.getFeedTitle(key), key, self.config, self.updateDbusHandler)
             self.disp.connect("feed-closed", self.onFeedClosed)
 
     def onFeedClosed(self, object, key):
@@ -897,6 +907,10 @@ class FeedingIt:
         # Need to check for internet connection
         # If no internet connection, try again in 10 minutes:
         # gobject.timeout_add(int(5*3600000), self.automaticUpdate)
+        file = open("/home/user/.feedingit/feedingit_widget.log", "a")
+        from time import gmtime, strftime
+        file.write("App: %s\n" % strftime("%a, %d %b %Y %H:%M:%S +0000", time()))
+        file.close()
         self.button_update_clicked(None, None)
         return True
     
