@@ -32,7 +32,7 @@ import feedparser
 import time
 import urllib2
 from BeautifulSoup import BeautifulSoup
-from urlparse import urlparse
+from urlparse import urljoin
 
 #CONFIGDIR="/home/user/.feedingit/"
 
@@ -65,16 +65,16 @@ class ImageHandler:
         filename = self.configdir+key+".d/"+getId(url)
         if not isfile(filename):
             try:
-                if url.startswith("http"):
-                    f = urllib2.urlopen(url)
-                else:
-                    f = urllib2.urlopen(baseurl+"/"+url)
+                #if url.startswith("http"):
+                #    f = urllib2.urlopen(url)
+                #else:
+                f = urllib2.urlopen(urljoin(baseurl,url))
                 outf = open(filename, "w")
                 outf.write(f.read())
                 f.close()
                 outf.close()
             except:
-                print "Could not download" + url
+                print "Could not download " + url
         if filename in self.images:
             self.images[filename] += 1
         else:
@@ -172,7 +172,7 @@ class Feed:
                if not id in self.ids:
                    soup = BeautifulSoup(self.getArticle(tmpEntry)) #tmpEntry["content"])
                    images = soup('img')
-                   baseurl = ''.join(urlparse(tmpEntry["link"])[:-1])
+                   baseurl = tmpEntry["link"]
                    if imageCache:
                       for img in images:
                           try:
@@ -180,7 +180,7 @@ class Feed:
                             img['src']=filename
                             tmpEntry["images"].append(filename)
                           except:
-                              print "Error downloading image %s" %img
+                              print "Error downloading image %s" % img
                    tmpEntry["contentLink"] = configdir+self.uniqueId+".d/"+id+".html"
                    file = open(tmpEntry["contentLink"], "w")
                    file.write(soup.prettify())
@@ -404,7 +404,7 @@ class ArchivedArticles(Feed):
                     f.close()
                     soup = BeautifulSoup(html)
                     images = soup('img')
-                    baseurl = ''.join(urlparse(entry["link"])[:-1])
+                    baseurl = entry["link"]
                     for img in images:
                         filename = self.imageHandler.addImage(self.uniqueId, baseurl, img['src'])
                         #filename = configdir+self.uniqueId+".d/"+getId(img['src'])
